import { fromMarkerData, toMarkerData } from './markerData.js';
import { fromWorkspaceEdit, toWorkspaceEdit } from './workspaceEdit.js';
/**
 * Convert a Monaco editor code action to an LSP code action.
 *
 * @param codeAction The Monaco code action to convert.
 * @returns The code action as an LSP code action.
 */
export function fromCodeAction(codeAction) {
    var _a;
    return {
        title: codeAction.title,
        diagnostics: (_a = codeAction.diagnostics) === null || _a === void 0 ? void 0 : _a.map(fromMarkerData),
        disabled: codeAction.disabled
            ? {
                reason: codeAction.disabled
            }
            : undefined,
        edit: codeAction.edit ? fromWorkspaceEdit(codeAction.edit) : undefined,
        kind: codeAction.kind,
        isPreferred: codeAction.isPreferred
    };
}
/**
 * Convert an LSP code action to a Monaco editor code action.
 *
 * @param codeAction The LSP code action to convert.
 * @param Uri The Monaco Uri constructor.
 * @returns The code action as Monaco editor code action.
 */
export function toCodeAction(codeAction, Uri) {
    var _a, _b;
    return {
        title: codeAction.title,
        diagnostics: (_a = codeAction.diagnostics) === null || _a === void 0 ? void 0 : _a.map((diagnostic) => toMarkerData(diagnostic, Uri)),
        disabled: (_b = codeAction.disabled) === null || _b === void 0 ? void 0 : _b.reason,
        edit: codeAction.edit ? toWorkspaceEdit(codeAction.edit, Uri) : undefined,
        kind: codeAction.kind,
        isPreferred: codeAction.isPreferred
    };
}
