import { fromRange, toRange } from './range.js';
import { fromSymbolKind, toSymbolKind } from './symbolKind.js';
import { fromSymbolTag, toSymbolTag } from './symbolTag.js';
/**
 * Convert a Monaco editor document symbol to an LSP document symbol.
 *
 * @param documentSymbol The Monaco document symbol to convert.
 * @returns The document symbol as an LSP document symbol.
 */
export function fromDocumentSymbol(documentSymbol) {
    var _a;
    return {
        children: (_a = documentSymbol.children) === null || _a === void 0 ? void 0 : _a.map(fromDocumentSymbol),
        detail: documentSymbol.detail || undefined,
        kind: fromSymbolKind(documentSymbol.kind),
        name: documentSymbol.name,
        range: fromRange(documentSymbol.range),
        selectionRange: fromRange(documentSymbol.selectionRange),
        tags: documentSymbol.tags.map(fromSymbolTag)
    };
}
/**
 * Convert an LSP document symbol to a Monaco editor document symbol.
 *
 * @param documentSymbol The LSP document symbol to convert.
 * @returns The document symbol as Monaco editor document symbol.
 */
export function toDocumentSymbol(documentSymbol) {
    var _a, _b, _c, _d;
    return {
        children: (_a = documentSymbol.children) === null || _a === void 0 ? void 0 : _a.map(toDocumentSymbol),
        detail: (_b = documentSymbol.detail) !== null && _b !== void 0 ? _b : '',
        kind: toSymbolKind(documentSymbol.kind),
        name: documentSymbol.name,
        range: toRange(documentSymbol.range),
        selectionRange: toRange(documentSymbol.selectionRange),
        tags: (_d = (_c = documentSymbol.tags) === null || _c === void 0 ? void 0 : _c.map(toSymbolTag)) !== null && _d !== void 0 ? _d : []
    };
}
